magneticalc

# ``magneticalc``

package documentation

MagnetiCalc package initialization.

Module | `About_Dialog` | About_Dialog module.
Module | `API` | API module.
Module | `Assert_Dialog` | Assert_Dialog module.
Module | `Backend_CUDA` | Backend_CUDA module.
Module | `Backend_JIT` | Backend_JIT module.
Module | `Backend_Types` | Backend_Types module.
Module | `CalculationThread` | CalculationThread module.
Module | `CheckForUpdates_Dialog` | CheckForUpdates_Dialog module.
Module | `Comparison_Types` | Comparison_Types module.
Module | `ConditionalDecorator` | ConditionalDecorator module.
Module | `Config` | Config module.
Module | `Config_Group` | Config_Collection module.
Module | `Constants` | Constants module.
Module | `Constraint` | Constraint module.
Module | `Constraint_Editor` | Constraint_Editor module.
Module | `Debug` | Debug module.
Module | `Display_Widget` | Display_Widget module.
Module | `ExportContainer_Dialog` | ExportContainer_Dialog module.
Module | `Field` | Field module.
Module | `Field_Types` | Field_Types module.
Module | `Field_Widget` | Field_Widget module.
Module | `File_Menu` | File_Menu module.
Module | `Format` | Format module.
Module | `GUI` | GUI module.
Module | `Help_Menu` | Help_Menu module.
Module | `MagnetiCalc_Data` | MagnetiCalc_Data module.
Module | `Menu` | Menu module.
Module | `Metric` | Metric module.
Module | `Metric_Presets` | Metric_Presets module.
Module | `Metric_Widget` | Metric_Widget module.
Module | `Model` | Model module.
Module | `ModelAccess` | Model access module.
Module | `Norm_Types` | Norm_Types module.
Module | `Options_Menu` | Options_Menu module.
Module | `OverridePadding_Dialog` | OverridePadding_Dialog module.
Module | `Parameters` | Parameters module.
Module | `Parameters_Widget` | Parameters_Widget module.
Module | `Perspective_Presets` | Perspective_Presets module.
Module | `Perspective_Widget` | Perspective_Widget module.
Module | `Project` | Project module.
Module | `QCheckboxConfig` | QCheckboxConfig module.
Module | `QMessageBox2` | QMessageBox2 module.
Module | `QTableView2` | QTableView2 module.
Package | `QtWidgets2` | MagnetiCalc package initialization.
Module | `SamplingVolume` | Sampling volume module.
Module | `SamplingVolume_Widget` | SamplingVolume_Widget module.
Module | `SidebarLeft` | SidebarLeft module.
Module | `SidebarRight` | SidebarRight module.
Module | `Statusbar` | Statusbar module.
Module | `Theme` | Theme module.
Module | `Usage_Dialog` | Usage_Dialog module.
Module | `Validatable` | Validatable module.
Module | `Version` | Version module.
Module | `View_Menu` | View_Menu module.
Module | `VisPyCanvas` | VisPyCanvas module.
Module | `Wire` | Wire module.
Module | `Wire_Menu` | Wire_Menu module.
Module | `Wire_Presets` | Wire_Presets module.
Module | `Wire_Widget` | Wire_Widget module.
Module | `__main__` | MagnetiCalc main module.